@@ -11,9 +11,11 @@ from Accuinsight.modeler.core.func import get_time
 from Accuinsight.modeler.core.get_for_visual import roc_pr_curve, get_true_y, get_visual_info_regressor
 from Accuinsight.modeler.core.sklearnModelType import REGRESSION, CLASSIFICATION
 from Accuinsight.modeler.core.LcConst.LcConst import ALL_MODEL_PARAMS, SELECTED_PARAMS, SELECTED_METRICS, VALUE_ERROR, \
-    LOGGING_TIME, LOGGING_RUN_ID, FITTED_MODEL, USER_ID, RUN_OBJ_NAME
+    LOGGING_TIME, LOGGING_RUN_ID, FITTED_MODEL, USER_ID, RUN_OBJ_NAME, RUN_MODEL_JSON_PATH, RUN_MODEL_VISUAL_JSON_PATH, \
+    RUN_MODEL_SHAP_JSON_PATH, RUN_MODEL_JOBLIB_PATH
 from Accuinsight.modeler.core.Run.RunInfo.RunInfo import set_current_runs, clear_runs, \
-    set_git_meta, set_python_dependencies, set_run_name, set_model_json_path, set_visual_json_path, set_model_file_path, set_prefix_path, set_best_model_joblib_path, _set_result_path, set_shap_json_path
+    set_git_meta, set_python_dependencies, set_run_name, set_model_json_path, set_visual_json_path, set_model_file_path, \
+    set_prefix_path, set_best_model_joblib_path, _set_result_path, set_shap_json_path
 from Accuinsight.modeler.utils.dependency.dependencies import gather_sources_and_dependencies
 from Accuinsight.modeler.core.LcConst import LcConst
 from Accuinsight.modeler.utils.os_getenv import is_in_ipython, get_current_notebook, get_os_env
@@ -245,7 +247,7 @@ class accuinsight(Common):
                 self.shap_value = shap_value(self.model_name, self.xtrain, self.feature_name)
                 
                 # path for shap.json
-                shap_json_full_path = self.dict_path['shap_json_full']
+                shap_json_full_path = self.dict_path[RUN_MODEL_SHAP_JSON_PATH]
                 set_shap_json_path(self.dict_path['shap_json'])
                 
                 with open(shap_json_full_path, 'w', encoding='utf-8') as save_file:
@@ -255,7 +257,7 @@ class accuinsight(Common):
             if any(i in self.fitted_model for i in CLASSIFICATION) or self.all_model_params['metric'] in metricsLightgbm.CLASSIFICATION:
 
                 # path for visual.json
-                visual_json_full_path = self.dict_path['visual_json_full']
+                visual_json_full_path = self.dict_path[RUN_MODEL_VISUAL_JSON_PATH]
                 set_visual_json_path(self.dict_path['visual_json'])
 
                 with open(visual_json_full_path, 'w', encoding='utf-8') as save_file1:
@@ -270,11 +272,11 @@ class accuinsight(Common):
                     self.summary_info['True_y'] = None
                     self.summary_info['Predicted_y'] = None
 
-            self.summary_info['ValueError'] = self.error_log
+            self.summary_info[VALUE_ERROR] = self.error_log
 
-            if not self.summary_info['ValueError']:
+            if not self.summary_info[VALUE_ERROR]:
                 # path for model_info.json
-                model_json_full_path = self.dict_path['model_json_full']
+                model_json_full_path = self.dict_path[RUN_MODEL_JSON_PATH]
                 set_model_json_path(self.dict_path['model_json'])
 
                 with open(model_json_full_path, 'w', encoding='utf-8') as save_file2:
@@ -284,7 +286,7 @@ class accuinsight(Common):
                 pass
 
             # model save
-            save_model_path = self.dict_path['save_model_joblib'] + self.summary_info[FITTED_MODEL] + '-' + self.summary_info[LOGGING_RUN_ID] +'.joblib'
+            save_model_path = self.dict_path[RUN_MODEL_JOBLIB_PATH] + self.summary_info[FITTED_MODEL] + '-' + self.summary_info[LOGGING_RUN_ID] +'.joblib'
             path_for_setting_model_joblib = self.dict_path['save_model_dir'] + '/' + self.summary_info[FITTED_MODEL] + '-' + self.summary_info[LOGGING_RUN_ID] +'.joblib'
 
             set_best_model_joblib_path(path_for_setting_model_joblib)
