@@ -28,7 +28,7 @@ class DeployLogRestApi:
     def __init__(self, host_url, port, uri):
         self.base_url = 'http://' + host_url + ':' + str(port) + '/' + uri
 
-    def call_rest_api(self, method, param, mode="logging"):
+    def call_rest_api(self, method, param, mode):
         store = MonitoringDeployRestStore(ModelerHostCreds(self.base_url))
         response = store.call_endpoint(method, param, mode)
 
