@@ -4,13 +4,15 @@ class DeployLog:
     """
 
     def __init__(self):
+        self.run_id = None
+        self._response_data = None
+
         self._start_time = None
         self._end_time = None
         self._req_method = None
         self._req_url = None
         self._req_body = None
         self._status_code = None
-        self._response_data = None
 
     def __eq__(self, other):
         if type(other) is type(self):
@@ -18,6 +20,24 @@ class DeployLog:
             return self.__dict__ == other.__dict__
         return False
 
+    @property
+    def run_id(self):
+        """String the deploy api response."""
+        return self._run_id
+
+    @run_id.setter
+    def run_id(self, run_id):
+        self._run_id = run_id
+
+    @property
+    def response_data(self):
+        """String the deploy api response."""
+        return self._response_data
+
+    @response_data.setter
+    def response_data(self, response_data):
+        self._response_data = response_data
+
     @property
     def start_time(self):
         """Start time of the deploy api requested."""
@@ -72,14 +92,6 @@ class DeployLog:
     def status_code(self, status_code):
         self._status_code = status_code
 
-    @property
-    def response_data(self):
-        """String the deploy api response."""
-        return self._response_data
-
-    @response_data.setter
-    def response_data(self, response_data):
-        self._response_data = response_data
 
     @classmethod
     def from_proto(cls, proto):
@@ -89,6 +101,12 @@ class DeployLog:
         """Create and return backend API parameter"""
         import time, json
 
+        if self.run_id is None:
+            raise Exception("run_id cannot be None")
+
+        if self.response_data is None:
+            raise Exception("response_data cannot be None")
+
         if self.start_time is None:
             raise Exception("start_time cannot be None")
 
@@ -104,11 +122,7 @@ class DeployLog:
         if self.status_code is None:
             raise Exception("status_code cannot be None")
 
-        if self.response_data is None:
-            raise Exception("response_data cannot be None")
-
         data = dict()
-
         data['createdAt'] = time.strftime('%Y-%m-%d %H:%M:%S', time.localtime(int(self.start_time)))
         data['endAt'] = time.strftime('%Y-%m-%d %H:%M:%S', time.localtime(int(self.end_time)))
         data['duration'] = round(self.end_time - self.start_time, 3)
@@ -116,6 +130,9 @@ class DeployLog:
         data['requestMethod'] = self.req_method
         data['requestBody'] = self.req_body
         data['statusCode'] = self.status_code
+
+
+        data['run_id'] = self.run_id
         data['response'] = self.response_data
 
         return json.dumps(data, indent=2)
