@@ -8,8 +8,8 @@ from Accuinsight.modeler.utils.rest_utils import call_endpoint, extract_api_info
 from Accuinsight.modeler.utils.os_getenv import get_os_env
 from Accuinsight.modeler.core.Run.ParseRun import BaseParser
 from Accuinsight.modeler.core.Run.RunInfo.RunInfo import dict_to_list
-from Accuinsight.modeler.core.LcConst.LcConst import RUN_OBJ_NAME, SOURCE_FILE_GIT_META, PYTHON_DEPENDENCY, \
-    SOURCE_FILE_GIT_REPO, SOURCE_FILE_GIT_COMMIT_ID
+from Accuinsight.modeler.core.LcConst.LcConst import SOURCE_FILE_GIT_META, PYTHON_DEPENDENCY, SOURCE_FILE_GIT_REPO, \
+    SOURCE_FILE_GIT_COMMIT_ID
 from Accuinsight.modeler.entities.lc_run_info import LcRunInfo as EntityRunInfo
 from Accuinsight.modeler.core.LcConst import LcConst
 from Accuinsight.modeler.entities.lc_artifact import LcArtifact as EntityArtifact
@@ -77,9 +77,6 @@ class RestStore(LcAbstractStore):
         :return: The ID of the created Run object
         """
 
-        # get current run meta data
-        run_name = current_run_meta[RUN_OBJ_NAME].split('-')[0]
-
         # read workspace environment
         # project_id, workspace_id, experiment_id and user_id
         env_value = get_os_env()
