@@ -13,7 +13,7 @@ def get_os_env(env_type='LC', env_path=None, env_file=None):
 
     env_value = {}
     if env_path is None:
-        env_path = '/home/work'
+        env_path = '/Users/a10053'
     if env_file is None:
         env_file = '.env'
 
@@ -43,15 +43,19 @@ def get_current_notebook():
         # '/home/notebook/.jupyter/lab/workspaces'
         if os.path.isdir(target_path):  # if jupyter lab
             file_lists = list()
+            file_name = None
             for (dir_path, dir_names, file_names) in os.walk(target_path):
                 for fn in file_names:
                     if not fn.endswith('.swp'):
-                        if 'auto' in fn:
-                            continue
+                        if 'default' in fn:
+                            file_name = fn
+                            break
                         file_lists.append(fn)
-                    break
 
-            with open(target_path + '/' + file_lists[0], 'r') as tf:
+            if not file_name:
+                file_name = file_lists[0]
+
+            with open(target_path + '/' + file_name, 'r') as tf:
                 strlines = tf.readlines()
                 json_file = json.loads(strlines[0])
                 return json_file['data']['layout-restorer:data']['main']['current'].split(':')[1]
